**Example 1: 删除即时转码模板**



Input: 

```
tccli vod DeleteJustInTimeTranscodeTemplate --cli-unfold-argument  \
    --Name testtempaltename
```

Output: 
```
{
    "Response": {
        "RequestId": "abc"
    }
}
```

